@@ -36,8 +36,8 @@ def automate(filepath):
                 continue
 
             # create storage folder
-            if not os.path.exists(cmpd):
-                os.mkdir(cmpd)
+            # if not os.path.exists(cmpd):
+                # os.mkdir(cmpd)
             # call the pubchem record, classify, sort toxic records, match unfound records
 
             try:
